pub struct BatchProcessor { /* private fields */ }Expand description
Batch processor for preparing text inputs for embedding models.
Implementations
Sourceimpl BatchProcessor
impl BatchProcessor
Sourcepub fn new(
tokenizer: Tokenizer,
model: EmbeddingModel,
max_batch_size: usize,
) -> Self
pub fn new( tokenizer: Tokenizer, model: EmbeddingModel, max_batch_size: usize, ) -> Self
Create a new batch processor.
Sourcepub fn max_batch_size(&self) -> usize
pub fn max_batch_size(&self) -> usize
Get the maximum batch size.
Sourcepub fn prepare_texts(&self, texts: &[String], is_query: bool) -> Vec<String>
pub fn prepare_texts(&self, texts: &[String], is_query: bool) -> Vec<String>
Prepare texts for embedding, optionally applying model-specific prefixes.
Sourcepub fn tokenize_batch(&self, texts: &[String]) -> Result<PreparedBatch>
pub fn tokenize_batch(&self, texts: &[String]) -> Result<PreparedBatch>
Tokenize a batch of texts and prepare flat i64 arrays for ORT inference.
Sourcepub fn split_into_batches<'a>(&self, texts: &'a [String]) -> Vec<&'a [String]>
pub fn split_into_batches<'a>(&self, texts: &'a [String]) -> Vec<&'a [String]>
Split texts into batches of maximum size.